#########################
#         CBIO          #
#      TUTORIAL 2       #
#########################

#--INSPECT MISSINGNESS PATTERNS--#

#IMPORT PLINK FILES WITH MISSINGNESS INFORMATION
imiss <- read.table("~/plinkout/raw.imiss",header=T)
het <- read.table("~/plinkout/raw.het",header=T)

#CALCULATE CALL RATE, LOG10(F_FMISS) and mean heterozygosity
imiss$CALL_RATE <- 1-imiss$F_MISS
imiss$logF_MISS = log10(imiss[,6])
het$meanHet = (het$N.NM. - het$O.HOM.)/het$N.NM.
het$meanHet <- ifelse(het$meanHet=="NaN", c(0),c(het$meanHet))
imiss.het <- merge(het,imiss,by=c("FID","IID"))

problem <- subset(imiss.het,imiss.het$meanHet > 0.40)
problem2 <- subset(imiss.het,imiss.het$F_MISS > 0.03)

#GENERATE CALL RATE BY HETEROZYGOSITY PLOT
colors  <- densCols(imiss$logF_MISS,het$meanHet)
#pdf("pairs.imiss-vs-het.pdf")
plot(imiss$logF_MISS,het$meanHet, col=colors, xlim=c(-3,0),ylim=c(0.15,0.75),pch=20, xlab="Proportion of missing genotypes", ylab="Heterozygosity rate",axes=F)
axis(2,at=c(0.15,0.2,0.25,0.3,0.35,0.4,0.45,0.5,0.55,0.60,0.65,0.70,0.75),tick=T)
axis(1,at=c(-3,-2,-1,0),labels=c(0.001,0.01,0.1,1))
#Heterozygosity thresholds (Horizontal Line)
abline(h=mean(het$meanHet)-(2*sd(het$meanHet)),col="RED",lty=2)
abline(h=mean(het$meanHet)+(2*sd(het$meanHet)),col="RED",lty=2)
#Missing Data Thresholds (Vertical Line)
abline(v=-1.30103, col="BLUE", lty=2) #THRESHOLD=0.05
abline(v=-1.522879, col="RED", lty=2) #THRESHOLD=0.03


#--INSPECT RELATIONSHIPS AND ANCESTRY--#

#Load pairwise IBD files for the BMI data
b.gen <- read.table("/student_data/cbio2016/plink/clean/bmi.genome",header=T)

#Inspect pair-wise relationships in the BMI data
summary(b.gen$PI_HAT)
hist(b.gen$PI_HAT)
#Identify duplicates
dups <- b.gen[which(b.gen$PI_HAT>0.90),]
#Identify potentially related samples
checkrel <- b.gen[which(b.gen$PI_HAT > 0.20),]

#Load MDS files
b.mds <- read.table("~/plinkout/bmi.mds",header=T)
h.mds <- read.table("/student_data/cbio2016/plink/hapmap/hapmap.mds",header=T)

#Load hapmap ID file and merge with hapmap MDS file
h.id <- read.table("/student_data/cbio2016/plink/hapmap/hapmapid.txt",header=T)
hapmap.full <- merge(h.mds,h.id,by=c("FID","IID"))

#Generate an MDS plot of the HapMap data
#Note: black=asia, red=ceph, green=yoru
plot(hapmap.full$C1,hapmap.full$C2,col=hapmap.full$SAMPLE,xlab="MDS Coordinate 1",ylab="MDS Coordinate 2")

#Generate an MDS plot of the BMI data
plot(b.mds$C1,b.mds$C2,xlab="MDS Coordinate 1",ylab="MDS Coordinate 2")

#Check to see whether the MDS information correlates with our phenotype (BMI)
#Load phenotype file
b.phe <- read.table("/student_data/cbio2016/plink/clean/bmi.phe",header=T)
bmi.full <- merge(b.phe,b.mds,by=c("FID","IID"))
plot(bmi.full$C1,bmi.full$BMI)
model <- lm(bmi.full$BMI ~ bmi.full$C1+bmi.full$C2)
summary(model)

#Load SNP frequency file and generate histogram
b.frq <- read.table("~/plinkout/bmi.frq",header=T)
hist(b.frq$MAF,col=c("gray"))